@@ -107,7 +107,7 @@ class FirebirdConnection(DBAPI):
             self.printDebug(conn, id, 'QueryIns', 'result')
         return id
 
-    def _queryAddLimitOffset(self, query, start, end):
+    def _queryAddLimitOffset(cls, query, start, end):
         """Firebird slaps the limit and offset (actually 'first' and
         'skip', respectively) statement right after the select."""
         if not start:
@@ -117,11 +117,12 @@ class FirebirdConnection(DBAPI):
         else:
             limit_str = "SELECT FIRST %i SKIP %i" % (end-start, start)
 
-        match = self.limit_re.match(query)
+        match = cls.limit_re.match(query)
         if match and len(match.groups()) == 2:
             return ' '.join([limit_str, match.group(2)])
         else:
             return query
+    _queryAddLimitOffset = classmethod(_queryAddLimitOffset)
 
     def createTable(self, soClass):
         self.query('CREATE TABLE %s (\n%s\n)' % \
@@ -162,10 +163,8 @@ class FirebirdConnection(DBAPI):
         self.query("DROP TABLE %s" % tableName)
         self.query("DROP GENERATOR GEN_%s" % tableName)
 
-    def delColumn(self, tableName, column):
-        self.query('ALTER TABLE %s DROP %s' %
-                   (tableName,
-                    column.dbName))
+    def delColumn(self, sqlmeta, column):
+        self.query('ALTER TABLE %s DROP %s' % (sqlmeta.table, column.dbName))
 
     def columnsFromSchema(self, tableName, soClass):
         """
@@ -174,30 +173,33 @@ class FirebirdConnection(DBAPI):
         """
 
         fieldqry = """\
-        SELECT RDB$RELATION_FIELDS.RDB$FIELD_NAME as field,
-               RDB$TYPES.RDB$TYPE_NAME as t,
-               RDB$FIELDS.RDB$FIELD_LENGTH as flength,
-               RDB$FIELDS.RDB$FIELD_SCALE as fscale,
-               RDB$RELATION_FIELDS.RDB$NULL_FLAG as nullAllowed,
-               RDB$RELATION_FIELDS.RDB$DEFAULT_VALUE as thedefault,
-               RDB$FIELDS.RDB$FIELD_SUB_TYPE as blobtype
-        FROM RDB$RELATION_FIELDS
-        INNER JOIN RDB$FIELDS ON
-            (RDB$RELATION_FIELDS.RDB$FIELD_SOURCE = RDB$FIELDS.RDB$FIELD_NAME)
-        INNER JOIN RDB$TYPES ON (RDB$FIELDS.RDB$FIELD_TYPE =
-                                 RDB$TYPES.RDB$TYPE)
-        WHERE
-            (RDB$RELATION_FIELDS.RDB$RELATION_NAME = '%s')
-            AND (RDB$TYPES.RDB$FIELD_NAME = 'RDB$FIELD_TYPE')"""
+        SELECT rf.RDB$FIELD_NAME as field,
+               t.RDB$TYPE_NAME as t,
+               f.RDB$FIELD_LENGTH as flength,
+               f.RDB$FIELD_SCALE as fscale,
+               rf.RDB$NULL_FLAG as nullAllowed,
+               coalesce(rf.RDB$DEFAULT_SOURCE, f.rdb$default_source) as thedefault,
+               f.RDB$FIELD_SUB_TYPE as blobtype
+        FROM RDB$RELATION_FIELDS rf
+        INNER JOIN RDB$FIELDS f ON rf.RDB$FIELD_SOURCE = f.RDB$FIELD_NAME
+        INNER JOIN RDB$TYPES t ON f.RDB$FIELD_TYPE = t.RDB$TYPE
+        WHERE rf.RDB$RELATION_NAME = '%s'
+        AND t.RDB$FIELD_NAME = 'RDB$FIELD_TYPE'"""
 
         colData = self.queryAll(fieldqry % tableName.upper())
         results = []
         for field, t, flength, fscale, nullAllowed, thedefault, blobType in colData:
-            if field == 'id':
+            field = field.strip().lower()
+            if thedefault:
+                thedefault = thedefault.split(' ')[1]
+                if thedefault.startswith("'") and thedefault.endswith("'"):
+                    thedefault = thedefault[1:-1]
+            idName = str(soClass.sqlmeta.idName or 'id').upper()
+            if field.upper() == idName:
                 continue
             colClass, kw = self.guessClass(t, flength, fscale)
             kw['name'] = soClass.sqlmeta.style.dbColumnToPythonAttr(field).strip()
-            kw['dbName'] = field.strip()
+            kw['dbName'] = field
             kw['notNone'] = not nullAllowed
             kw['default'] = thedefault
             results.append(colClass(**kw))
@@ -224,3 +226,10 @@ class FirebirdConnection(DBAPI):
             return col.DateTimeCol, {}
         else:
             return col.Col, {}
+
+    def createEmptyDatabase(self):
+        self.module.create_database("CREATE DATABASE '%s' user '%s' password '%s'" % \
+                                            (self.db, self.user, self.password))
+
+    def dropDatabase(self):
+        self.module.drop_database()
