@@ -1,5 +1,5 @@
 """
-SQLObject 0.10.7
+SQLObject 0.11.1
 ----------------
 
 :author: Ian Bicking <ianb@colorstudy.com>
@@ -668,8 +668,8 @@ def deprecated(message, level=1, stacklevel=2):
     if warnings_level is not None and warnings_level <= level:
         warnings.warn(message, DeprecationWarning, stacklevel=stacklevel)
 
-#if sys.version_info[:3] < (2, 4, 0):
-#    deprecated("Support for Python 2.3 has been declared obsolete and will be removed in the next release of SQLObject")
+#if sys.version_info[:3] < (2, 5, 0):
+#    deprecated("Support for Python 2.4 has been declared obsolete and will be removed in the next release of SQLObject")
 
 def setDeprecationLevel(warning=1, exception=None):
     """
@@ -810,6 +810,7 @@ class SQLObject(object):
         # more.
         if not is_base:
             cls.q = sqlbuilder.SQLObjectTable(cls)
+            cls.j = sqlbuilder.SQLObjectTableWithJoins(cls)
 
         classregistry.registry(cls.sqlmeta.registry).addClass(cls)
 
@@ -994,6 +995,11 @@ class SQLObject(object):
         finally:
             self._SO_writeLock.release()
 
+        post_funcs = []
+        self.sqlmeta.send(events.RowUpdatedSignal, self, post_funcs)
+        for func in post_funcs:
+            func()
+
     def expire(self):
         if self.sqlmeta.expired:
             return
@@ -1046,6 +1052,11 @@ class SQLObject(object):
         if self.sqlmeta.cacheValues:
             setattr(self, instanceName(name), value)
 
+        post_funcs = []
+        self.sqlmeta.send(events.RowUpdatedSignal, self, post_funcs)
+        for func in post_funcs:
+            func()
+
     def set(self, _suppress_set_sig=False, **kw):
         if not self.sqlmeta._creating and not getattr(self.sqlmeta, "row_update_sig_suppress", False) and not _suppress_set_sig:
             self.sqlmeta.send(events.RowUpdateSignal, self, kw)
@@ -1133,6 +1144,11 @@ class SQLObject(object):
         finally:
             self._SO_writeLock.release()
 
+        post_funcs = []
+        self.sqlmeta.send(events.RowUpdatedSignal, self, post_funcs)
+        for func in post_funcs:
+            func()
+
     def _SO_selectInit(self, row):
         for col, colValue in zip(self.sqlmeta.columnList, row):
             if col.to_python:
@@ -1569,6 +1585,11 @@ class SQLObject(object):
         for func in post_funcs:
             func()
 
+        post_funcs = []
+        self.sqlmeta.send(events.RowDestroyedSignal, self, post_funcs)
+        for func in post_funcs:
+            func()
+
     def delete(cls, id, connection=None):
         obj = cls.get(id, connection=connection)
         obj.destroySelf()
